#delimit ;
clear all;


* replication materials for "Strategic Behavior by Market Intermediaries"



*#################################

* REVIEW INTERVAL FIGURE;
use "movie_reviews";
sort revreldiff;
egen m_mc = mean(mcscore), by(revreldiff);
by revreldiff: replace m_mc = . if _n > 1;
label var m_mc "Mean Review Score";
graph twoway hist revreldiff, 
	discrete xlabel(-14 -7 0 7 14 21 28) 
	xtitle("Days from Movie Release") 
	title("Movie Review Intervals 2011-2014") || 
	scatter m_mc revreldiff, yaxis(2) legend(off);
graph save fig1m, replace;
clear;
use "vg_reviews";
sort revreldiff;
egen m_mc = mean(mcscore), by(revreldiff);
by revreldiff: replace m_mc = . if _n > 1;
label var m_mc "Mean Review Score";
graph twoway hist revreldiff , 
	discrete xlabel(-14 -7 0 7 14 21 28 35 42 ) 
	xtitle("Days from Game Release")  
	title("Game Review Intervals 2011-2014") || 
	scatter m_mc revreldiff, yaxis(2)
	legend( rowgap(0) pos(1) ring(0) col(1) size(3) );
graph save fig1v, replace;
* FIG1: combined graph;
graph combine fig1m.gph fig1v.gph, col(1);
erase fig1m.gph;
erase fig1v.gph;


*#################################

* REVIEW TIMING ANALYSIS;
* MOVIES;
clear;
use movie_reviews; 
* SIMPLE MODEL;
xtreg late c.mcscore  
	  i.SID, r fe i(MID);
est store M1; 
* TWO-WAY INTERACTION;
xtreg late c.mcscore  c.mcscore#c.tnopen2  c.mcscore#c.early_yq 
	  i.SID, r fe i(MID);
est store M2; 
qui margins, at(mcscore=(.10(.10).90) early_yq  =(1 3) );
marginsplot , xdimension(mcscore) recastci(rspike)   
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	xtitle("Movie Review Score (.00)") 
	legend(order (3 "1 Prior Tie" 4 "3 Prior Ties") 	
	rowgap(0) pos(7) ring(0) col(1) size(3) );	
graph save m_2way_tie, replace;	
qui margins, at(mcscore=(.10(.10).90) tnopen2 =(.5 3.0) );
marginsplot , xdimension(mcscore) recastci(rspike)   
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	xtitle("Movie Review Score (.00)") 
	legend(order (3 "500 screens" 4 "3000 screens") 	
	rowgap(0) pos(7) ring(0) col(1) size(3) );	
graph save m_2way_screens, replace;	
* THREE-WAY INTERACTION;
xtreg late c.mcscore  c.mcscore#c.tnopen2#i.Stype c.mcscore#c.early_yq#i.Stype	
	 i.SID, r fe i(MID);
est store M3;
test 1.Stype#c.mcscore#c.tnopen2 = 2.Stype#c.mcscore#c.tnopen2;
test 1.Stype#c.mcscore#c.tnopen2 = 3.Stype#c.mcscore#c.tnopen2;
test 2.Stype#c.mcscore#c.tnopen2 = 3.Stype#c.mcscore#c.tnopen2;
test 1.Stype#c.mcscore#c.early_yq = 2.Stype#c.mcscore#c.early_yq;
test 1.Stype#c.mcscore#c.early_yq = 3.Stype#c.mcscore#c.early_yq;
test 2.Stype#c.mcscore#c.early_yq = 3.Stype#c.mcscore#c.early_yq;
qui margins, at(mcscore=(.10(.10).90) early_yq  =(1 3) Stype=(1 2 3));
marginsplot , xdimension(mcscore) recastci(rspike)  by(Stype) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	byopt(title( "" ) cols(2)) xtitle("Movie Review Score (.00)") 
	legend(order (3 "1 Prior Tie" 4 "3 Prior Ties") 	
	rowgap(0) pos(1) ring(0) col(1) size(3) ); 
graph save m_3way_tie, replace;	
qui margins, at(mcscore=(.10(.10).90) tnopen2 =(.5 3.0) Stype=(1 2 3));
marginsplot , xdimension(mcscore) recastci(rspike)  by(Stype) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	byopt(title( "" ) cols(2)) xtitle("Movie Review Score (.00)") 
	legend(order (3 "500 screens" 4 "3000 screens") 
	rowgap(0) pos(1) ring(0) col(1) size(3) ); 
graph save m_3way_screens, replace;
clear;

* VIDEO GAMES;
use vg_reviews; 
* SIMPLE MODEL;
xtreg late c.mcscore 
	i.SID, r fe i(GID);
est store V1;
* TWO-WAY INTERACTION;
xtreg late c.mcscore c.mcscore#c.GIDN c.mcscore#c.early_yq
	i.SID, r fe i(GID);
est store V2;
qui margins, at(mcscore=(.10(.10).90) early_yq  =(0 4));
marginsplot , xdimension(mcscore) recastci(rspike)   
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	xtitle("Game Review Score (.00)") 
	legend(order (3 "0 Prior Ties" 4 "4 Prior Ties") 
	rowgap(0) pos(1) ring(0) col(1) size(3) );	
graph save v_2way_ties, replace;	
qui margins, at(mcscore=(.10(.10).90) GIDN =(.010 .100) );
marginsplot , xdimension(mcscore) recastci(rspike)   
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	xtitle("Game Review Score (.00)") 
	legend(order (3 "10 Reviews" 4 "100 Reviews") 
	rowgap(0) pos(1) ring(0) col(1) size(3) );	
graph save v_2way_scale, replace;	
* THREE-WAY INTERACTION;	
xtreg late c.mcscore c.mcscore#c.GIDN#i.specialist c.mcscore#c.early_yq#i.specialist
	i.SID, r fe i(GID);
est store V3; 
test 0.specialist#c.mcscore#c.GIDN = 1.specialist#c.mcscore#c.GIDN;	
test 0.specialist#c.mcscore#c.early_yq = 1.specialist#c.mcscore#c.early_yq;	
qui margins, at(mcscore=(.10(.10).90) early_yq  =(0 4) specialist=(0 1));
marginsplot , xdimension(mcscore) recastci(rspike)  by(specialist) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	byopt(title( "" ) cols(1)) 
	xtitle("Game Review Score (.00)") 
	legend(order (3 "0 Prior Ties" 4 "4 Prior Ties") 
	rowgap(0) pos(1) ring(0) col(1) size(3) );	
graph save v_3way_ties, replace;	
qui margins, at(mcscore=(.10(.10).90) GIDN =(.010 .100) specialist=(0 1));
marginsplot , xdimension(mcscore) recastci(rspike)  by(specialist) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S))  
	title("") ytitle("Late Review") 
	byopt(title( "" ) cols(1)) 
	xtitle("Game Review Score (.00)") 
	legend(order (3 "10 Reviews" 4 "100 Reviews") 
	rowgap(0) pos(1) ring(0) col(1) size(3) );	
graph save v_3way_scale, replace;	

* COMBINED TABLE;
esttab M1 M2 V1 V2, cells(b(nostar fmt(3))  p(par fmt(3))) 
	stats(r2 N, fmt(%9.3f %9.0g) ) drop( *SID) label tex
	coeflabels (
		mcscore "Review Score"
		c.mcscore#c.tnopen2 "Score X Screens"
		c.mcscore#c.early_yq "Score X Prior Ties"
		1.Stype#c.mcscore#c.tnopen2 "Score X Screens X Local"
		2.Stype#c.mcscore#c.tnopen2 "Score X Screens X Natl"		
		3.Stype#c.mcscore#c.tnopen2 "Score X Screens X Ent"		
		1.Stype#c.mcscore#c.early_yq "Score X Ties X Local"
		2.Stype#c.mcscore#c.early_yq "Score X Ties X Natl"		
		3.Stype#c.mcscore#c.early_yq "Score X Ties X Ent"	
		c.mcscore#c.GIDN  "Score X Scale"
		c.mcscore#c.early_yq "Score X Prior Ties"
		0.specialist#c.mcscore#c.GIDN "Score X Scale X Gen"
		1.specialist#c.mcscore#c.GIDN "Score X Scale X Spec"
		0.specialist#c.mcscore#c.early_yq "Score X Ties X Gen"
		1.specialist#c.mcscore#c.early_yq "Score X Ties X Spec"
		) 
; 

* COMBINED TABLE WITH 3-WAY INTERACTIONS;
esttab M3 V3, cells(b(nostar fmt(3))  p(par fmt(3))) 
	stats(r2 N, fmt(%9.3f %9.0g) ) drop( *SID) label tex
	coeflabels (
		mcscore "Review Score"
		c.mcscore#c.tnopen2 "Score X Screens"
		c.mcscore#c.early_yq "Score X Prior Ties"
		1.Stype#c.mcscore#c.tnopen2 "Score X Screens X Local"
		2.Stype#c.mcscore#c.tnopen2 "Score X Screens X Natl"		
		3.Stype#c.mcscore#c.tnopen2 "Score X Screens X Ent"		
		1.Stype#c.mcscore#c.early_yq "Score X Ties X Local"
		2.Stype#c.mcscore#c.early_yq "Score X Ties X Natl"		
		3.Stype#c.mcscore#c.early_yq "Score X Ties X Ent"	
		c.mcscore#c.GIDN  "Score X Scale"
		c.mcscore#c.early_yq "Score X Prior Ties"
		0.specialist#c.mcscore#c.GIDN "Score X Scale X Gen"
		1.specialist#c.mcscore#c.GIDN "Score X Scale X Spec"
		0.specialist#c.mcscore#c.early_yq "Score X Ties X Gen"
		1.specialist#c.mcscore#c.early_yq "Score X Ties X Spec"
		) 
; 

* COMBINED FIGURES;
graph combine m_2way_tie.gph v_2way_ties.gph 
	m_2way_screens.gph v_2way_scale.gph, 
	title("Review Publication Timing - Two-way Interactions");
graph combine m_3way_tie.gph m_3way_screens.gph, 
	title("Movie Review Publication Timing - Three-way Interactions");
graph combine v_3way_ties.gph v_3way_scale.gph, 
	title("Game Review Publication Timing - Three-way Interactions");
erase m_2way_tie.gph;
erase v_2way_ties.gph; 
erase m_2way_screens.gph; 
erase v_2way_scale.gph;
erase m_3way_tie.gph;
erase m_3way_screens.gph;
erase v_3way_ties.gph;
erase v_3way_scale.gph;


* THRESHOLD EFFECTS;
* MOVIES;
use movie_reviews;
xtreg late i.SID i.mcscore_orig if tnopen2 >= 1 , r fe i(MID);
predict phat if tnopen2 >= 1;
xtreg late i.SID i.mcscore_orig if tnopen2  < 1 , r fe i(MID);
predict phat2 if tnopen2 < 1;
replace phat = phat2 if tnopen2 < 1;
gen big = (tnopen2 >= 1); 
binscatter phat mcscore_orig , linetype(connect) nq(12) xline(40 61) 
	msymbol(O T)
	by(big) legend(order (1 "<1000 Screens" 2 ">1000 Screens") 	
	rowgap(0) pos(9) ring(0) col(1) size(3) )
	ytitle("Predicted Late Review Probability") 
	xtitle("Movie Review Score") 
	text(.6 63 "Green Score", box place(e))
	text(.6 43 "Yellow Score", box place(e))
	text(.6 25 "Red Score", box place(e));
graph save movie_threshold, replace; 
clear;

* VIDEO GAMES;
use vg_reviews;
xtreg late i.SID i.mcscore_orig if GIDN >= .06 , r fe i(GID);
predict phat if GIDN >= .06;
xtreg late i.SID i.mcscore_orig if GIDN < .06 , r fe i(GID);
predict phat2 if GIDN < .06;
replace phat = phat2 if GIDN < .06;
gen big = (GIDN >= .06);
binscatter phat mcscore_orig , linetype(connect) nq(12) xline(50  75) 
	by(big) legend(order (1 "<60 Reviews" 2 ">60 Reviews") 	
	rowgap(0) pos(7) ring(0) col(1) size(3) )
	ytitle("Predicted Late Review Probability") 
	xtitle("Video Game Review Score") 
	xscale(range(20 100))
	msymbol(O T)
	text(.7 80 "Green Score", box place(e))
	text(.7 56 "Yellow Score", box place(e))
	text(.7 40 "Red Score", box place(e));
graph save vg_threshold, replace; 
* COMBINED;
graph combine movie_threshold.gph vg_threshold.gph, 
	col(1) title("Review Grade Thresholds");;
erase movie_threshold.gph;
erase vg_threshold.gph;


* ROBUSTNESS CHECKS;
* 1) EMBARGO;
* NO APPARENT DIFFERENCES WHEN SPLITTING BY PROPORTION OF EARLY/LATE REVIEWS;
use movie_reviews, clear;
xtreg late c.mcscore  c.mcscore#c.tnopen2  c.mcscore#c.early_yq
	 i.SID
	if MID_late >= .5, r fe i(MID);
est store M1;
xtreg late c.mcscore  c.mcscore#c.tnopen2  c.mcscore#c.early_yq
	 i.SID
	if MID_late < .5, r fe i(MID);
est store M2;
use vg_reviews, clear;
xtreg late c.mcscore  c.mcscore#c.GIDN  c.mcscore#c.early_yq
	 i.SID
	if GID_late >= .5, r fe i(GID);
est store V1;
xtreg late c.mcscore  c.mcscore#c.GIDN  c.mcscore#c.early_yq
	 i.SID
	if GID_late < .5, r fe i(GID);
est store V2;
esttab M1 M2 V1 V2, cells(b(nostar fmt(3))  p(par fmt(3))) 
	stats(N r2) drop( *SID) label tex
		coeflabels (
		mcscore "Review Score"
		c.mcscore#c.tnopen2 "Score X Screens"
		c.mcscore#c.GIDN  "Score X Scale"
		c.mcscore#c.early_yq "Score X Prior Ties"
		c.mcscore#c.early_yq "Score X Prior Ties")
;


* 2) CROWDING EFFECTS;
* NO APPARENT DIFFERENCES WHEN SPLITTING BY COMPETING RELEASE BUCKETS;
use movie_reviews, clear;
gen crowd = 1;
replace crowd = 2 if crowd_day >= 8;
xtreg late c.mcscore  c.mcscore#c.tnopen2  c.mcscore#c.early_yq
	 i.SID if crowd == 1
	, r fe i(MID);
est store M1;	
xtreg late c.mcscore  c.mcscore#c.tnopen2  c.mcscore#c.early_yq
	 i.SID if crowd == 2
	, r fe i(MID);
est store M2;
use vg_reviews, clear;
gen crowd = 1;
replace crowd = 2 if crowd_day >= 5;
xtreg late c.mcscore  c.mcscore#c.GIDN  c.mcscore#c.early_yq
	 i.SID if crowd == 1
	, r fe i(GID);
est store V1;	
xtreg late c.mcscore  c.mcscore#c.GIDN  c.mcscore#c.early_yq
	 i.SID if crowd == 2
	, r fe i(GID);
est store V2;
esttab M1 M2 V1 V2, cells(b(nostar fmt(3))  p(par fmt(3))) 
	stats(N r2) drop( *SID) label tex
		coeflabels (
		mcscore "Review Score"
		c.mcscore#c.tnopen2 "Score X Screens"
		c.mcscore#c.GIDN  "Score X Scale"
		c.mcscore#c.early_yq "Score X Prior Ties")
;
clear;


*#################################

* PAIRWISE ANALYSIS;

* MOVIES;
use movie_pairs; 
* BASE MODEL;
reghdfe score_diff_dir 1.obs, vce(r) absorb(PairID MID) keepsingletons;
est store M1;
* INTERACTIONS;
xtreg score_diff_dir 1.obs##i.pairtype 1.obs##c.overlap_pct , r fe i(MID);
est store M2;
* INTERACTION PLOTS;
margins obs, at(overlap_pct = (0(.1)1));
marginsplot, xdimension(overlap_pct)  recastci(rspike) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S)) 
	title("") ytitle("Score Difference") 
	xtitle("Movie Pair Overlap (%)") 
	legend(order (3 "No Observation" 4 "Observation") rowgap(0) pos(7) ring(0) col(1) size(3)  );
graph save movie_pairoverlap, replace;
margins obs, at(pairtype  = (1(1)9));
marginsplot, xdimension(pairtype) recast(scatter) recastci(rspike) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S)) 
	title("") ytitle("Score Difference") 
	xtitle("Movie Pair Type (Leader - Follower)") xlabel(, angle(45) labsize(small)) 
	legend(off);
graph save movie_pairtypes, replace; 
* FULL FE CHECKS;
reghdfe score_diff_dir 1.obs##c.overlap_pct , vce(r) absorb(PairID MID) keepsingletons;
est store M2A;
reghdfe score_diff_dir 1.obs#1.pairtype 1.obs#2.pairtype 1.obs#3.pairtype 
	1.obs#4.pairtype 1.obs#5.pairtype 1.obs#6.pairtype 1.obs#7.pairtype 
	1.obs#8.pairtype 1.obs#9.pairtype, vce(r) absorb(PairID MID) keepsingletons;
est store M2B;
* joint tests within types;
* local respond most to national;
test 1.obs#1.pairtype = 1.obs#2.pairtype;
test 1.obs#1.pairtype = 1.obs#3.pairtype;
test 1.obs#2.pairtype = 1.obs#3.pairtype;   
* nationals not responding to anyone;
test 1.obs#4.pairtype = 1.obs#5.pairtype;
test 1.obs#4.pairtype = 1.obs#6.pairtype;
test 1.obs#5.pairtype = 1.obs#6.pairtype;  
* entertainment respond most to entertainment;
test 1.obs#7.pairtype = 1.obs#8.pairtype;
test 1.obs#7.pairtype = 1.obs#9.pairtype;
test 1.obs#8.pairtype = 1.obs#9.pairtype;  


* GAMES;
clear;
use vg_pairs; 
* BASE MODEL;
reghdfe score_diff_dir 1.obs, vce(r) absorb(PairID GID) keepsingletons;
est store V1;
xtreg score_diff_dir 1.obs##i.spectype 1.obs##c.overlap_pct , r fe i(GID);
est store V2;
* INTERACTION PLOTS;
margins obs, at(overlap_pct = (0(.1)1));
marginsplot, xdimension(overlap_pct)  recastci(rspike) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S)) 
	title("") ytitle("Score Difference") 
	xtitle("Video Game Pair Overlap (%)") legend(off);
graph save vg_pairoverlap, replace;
margins obs, at(spectype  = (1(1)4));
marginsplot, xdimension(spectype) recast(scatter) recastci(rspike) 
	plot1opts(msymbol(T)) plot2opts(msymbol(S)) 
	title("") ytitle("Score Difference") 
	xtitle("Video Game Pair Type (Leader - Follower)") xlabel(, angle(45) labsize(small)) legend(off);
graph save vg_pairtypes, replace; 	
* FULL FE CHECKS;
reghdfe score_diff_dir 1.obs##c.overlap_pct , vce(r) absorb(PairID GID) keepsingletons;
est store V2A;
reghdfe score_diff_dir 1.obs#1.spectype 1.obs#2.spectype 
	1.obs#3.spectype 1.obs#4.spectype, vce(r) absorb(PairID GID) keepsingletons;
est store V2B;
* joint tests within types;
* specialists respond more to generalists than pecialists;
test 1.obs#1.spectype = 1.obs#2.spectype;
* generalists respond more to generalists than specialists;
test 1.obs#3.spectype = 1.obs#4.spectype; 

* COMBINED TABLES AND FIGURES;
* MAIN TABLE;
esttab M1 M2 V1 V2, cells(b(nostar fmt(3))  p(par fmt(3)))   stats(r2 N, fmt(%9.3f %9.0g) )
	starlevels(+ 0.10 * 0.05 ** 0.01) drop() 
	label tex
	coeflabels (
		1.obs				 "Observation"
		1.obs#c.overlap_pct "Obs X Overlap"
		1.obs#1.pairtype  "Obs X Loc-Loc"
		1.obs#2.pairtype "Obs X Natl-Loc"
		1.obs#3.pairtype  "Obs X Ent-Loc"  
		1.obs#4.pairtype  "Obs X Loc-Natl" 
		1.obs#5.pairtype  "Obs X Natl-Natl" 
		1.obs#6.pairtype  "Obs X Ent-Natl"
		1.obs#7.pairtype "Obs X Loc-Ent" 
		1.obs#8.pairtype  "Obs X Natl-Ent"
		1.obs#9.pairtype "Obs X Ent-Ent"
		1.obs#1.spectype "Obs X Spec-Spec"
		1.obs#2.spectype "Obs X Gen-Spec" 
		1.obs#3.spectype "Obs X Spec-Gen"
		1.obs#4.spectype "Obs X Gen-Gen" 
		) 
; 
* THREE-WAY INTERACTIONS TABLE;
esttab M2 V2, cells(b(nostar fmt(3))  p(par fmt(3)))   stats(r2 N, fmt(%9.3f %9.0g) )
	starlevels(+ 0.10 * 0.05 ** 0.01) drop() 
	label tex
	coeflabels (
		1.obs				 "Observation"
		1.obs#c.overlap_pct "Obs X Overlap"
		1.obs#1.pairtype  "Obs X Loc-Loc"
		1.obs#2.pairtype "Obs X Natl-Loc"
		1.obs#3.pairtype  "Obs X Ent-Loc"  
		1.obs#4.pairtype  "Obs X Loc-Natl" 
		1.obs#5.pairtype  "Obs X Natl-Natl" 
		1.obs#6.pairtype  "Obs X Ent-Natl"
		1.obs#7.pairtype "Obs X Loc-Ent" 
		1.obs#8.pairtype  "Obs X Natl-Ent"
		1.obs#9.pairtype "Obs X Ent-Ent"
		1.pairtype  "Loc-Loc"
		2.pairtype "Natl-Loc"
		3.pairtype  "Ent-Loc"  
		4.pairtype  "Loc-Natl" 
		5.pairtype  "Natl-Natl" 
		6.pairtype  "Ent-Natl"
		7.pairtype "Loc-Ent" 
		8.pairtype  "Natl-Ent"
		9.pairtype "Ent-Ent"
		1.obs#1.spectype "Obs X Spec-Spec"
		1.obs#2.spectype "Obs X Gen-Spec" 
		1.obs#3.spectype "Obs X Spec-Gen"
		1.obs#4.spectype "Obs X Gen-Gen" 
		1.spectype "Spec-Spec"
		2.spectype "Gen-Spec" 
		3.spectype "Spec-Gen"
		4.spectype "Gen-Gen" 
		) 
; 
* FE TABLE;
esttab M2A M2B V2A V2B, cells(b(nostar fmt(3))  p(par fmt(3)))   stats(r2 N, fmt(%9.3f %9.0g) )
	starlevels(+ 0.10 * 0.05 ** 0.01) drop() 
	label tex
	coeflabels (
		1.obs				 "Observation"
		1.obs#c.overlap_pct "Obs X Overlap"
		1.obs#1.pairtype  "Obs X Loc-Loc"
		1.obs#2.pairtype "Obs X Natl-Loc"
		1.obs#3.pairtype  "Obs X Ent-Loc"  
		1.obs#4.pairtype  "Obs X Loc-Natl" 
		1.obs#5.pairtype  "Obs X Natl-Natl" 
		1.obs#6.pairtype  "Obs X Ent-Natl"
		1.obs#7.pairtype "Obs X Loc-Ent" 
		1.obs#8.pairtype  "Obs X Natl-Ent"
		1.obs#9.pairtype "Obs X Ent-Ent"
		1.obs#1.spectype "Obs X Spec-Spec"
		1.obs#2.spectype "Obs X Gen-Spec" 
		1.obs#3.spectype "Obs X Spec-Gen"
		1.obs#4.spectype "Obs X Gen-Gen" 
		) 
; 
* FIGURES;
graph combine movie_pairtypes.gph vg_pairtypes.gph, col(2)
	title("Review Pair Type and Score Differentiation");
graph combine movie_pairoverlap.gph vg_pairoverlap.gph, col(2)
	title("Review Pair Type and Score Differentiation");
erase movie_pairtypes.gph;
erase vg_pairtypes.gph;
erase movie_pairoverlap.gph;
erase vg_pairoverlap.gph;

